@@ -1,3 +1,7 @@
+from typing import Literal
+import logging
+
+
 class SantanderClientConfiguration:
     def __init__(
         self,
@@ -6,12 +10,16 @@ class SantanderClientConfiguration:
         cert: str,
         base_url: str,
         workspace_id: str = "",
+        log_request_response_level: Literal["ERROR", "ALL", "NONE"] = "ERROR",
+        logger: logging.Logger | None = None,
     ):
         self.client_id = client_id
         self.client_secret = client_secret
         self.workspace_id = workspace_id
         self.cert = cert
         self.base_url = base_url
+        self.log_request_response_level = log_request_response_level
+        self.logger = logger or logging.getLogger(__name__)
 
     def set_workspace_id(self, workspace_id: str):
         self.workspace_id = workspace_id
