@@ -1,14 +1,13 @@
 from decimal import ROUND_DOWN, Decimal
 import logging
 from itertools import cycle
+from time import sleep, time
 from typing import Literal
 import re
 import requests
+import pathlib
 
-from santander_sdk.api_client.exceptions import (
-    SantanderRequestError,
-    SantanderValueError,
-)
+from santander_sdk.api_client.exceptions import SantanderRequestError
 
 logger = logging.getLogger("santanderLogger")
 
@@ -51,7 +50,7 @@ def get_pix_key_type(chave: str) -> DictCodeTypes:
     elif len(only_numbers(chave)) == 13 and chave.startswith("+"):
         return "CELULAR"
     else:
-        raise SantanderValueError(f"Chave Pix em formato inválido: {chave}")
+        raise ValueError(f"Chave Pix em formato inválido: {chave}")
 
 
 def try_parse_response_to_json(response) -> dict | None:
@@ -62,26 +61,6 @@ def try_parse_response_to_json(response) -> dict | None:
     return error_content
 
 
-SANTANDER_STATUS_DESCRIPTIONS = {
-    200: "Sucesso",
-    201: "Recurso criado",
-    400: "Erro de informação do cliente",
-    401: "Não autorizado/Autenticado",
-    403: "Não Autorizado",
-    404: "Informação não encontrada",
-    406: "O recurso de destino não possui uma representação atual que seria aceitável",
-    422: "Entidade não processa/inadequada",
-    429: "O usuário enviou muitas solicitações em um determinado período",
-    500: "Erro de Servidor, Aplicação está fora",
-    501: "O servidor não oferece suporte à funcionalidade necessária para atender à solicitação",
-}
-
-
-def get_status_code_description(status_code: int | str) -> str:
-    """Retorna a descrição do status do Santander"""
-    return f"{status_code} - {SANTANDER_STATUS_DESCRIPTIONS.get(int(status_code), 'Erro desconhecido')}"
-
-
 def only_numbers(s):
     return re.sub("[^0-9]", "", s) if s else s
 
@@ -147,4 +126,35 @@ def document_type(document_number: str) -> Literal["CPF", "CNPJ"]:
         return "CPF"
     if len(document_number) == 14:
         return "CNPJ"
-    raise SantanderValueError('Unknown document type "{document_number}"')
+    raise ValueError('Unknown document type "{document_number}"')
+
+
+def get_content_from_url(url: str) -> bytes:
+    response = requests.get(url, headers={"User-Agent": "Mozilla/5.0"})
+    response.raise_for_status()
+    return response.content
+
+
+def save_bytes_to_file(content: bytes, file_path: str):
+    path = pathlib.Path(file_path)
+    path.write_bytes(content)
+    return str(path)
+
+
+def download_file(url: str, file_path: str):
+    content = get_content_from_url(url)
+    saved_path = save_bytes_to_file(content, file_path)
+    return saved_path
+
+
+def polling_until_condition(
+    func, conditional_func, timeout=60, interval=1, *args, **kwargs
+):
+    """Polling until a condition is met."""
+    end_time = time() + timeout
+    while time() <= end_time:
+        result = func(*args, **kwargs)
+        if conditional_func(result):
+            return result
+        sleep(interval)
+    raise TimeoutError("Timeout polling until condition is met")
