@@ -1,12 +1,9 @@
 from decimal import Decimal as D
-import logging
+import uuid
 from typing import cast
 
 from santander_sdk.api_client.client import SantanderApiClient
-from santander_sdk.api_client.exceptions import (
-    SantanderClientError,
-    SantanderValueError,
-)
+from santander_sdk.api_client.exceptions import SantanderClientError
 
 from santander_sdk.api_client.helpers import (
     get_pix_key_type,
@@ -19,7 +16,6 @@ from santander_sdk.types import (
     TransferPixResult,
 )
 
-logger = logging.getLogger("santanderLogger")
 PIX_ENDPOINT = "/management_payments_partners/v1/workspaces/:workspaceid/pix_payments"
 
 
@@ -29,14 +25,17 @@ def transfer_pix(
     value: D,
     description: str,
     tags: list[str] = [],
+    id: uuid.UUID | str | None = None,
 ) -> TransferPixResult:
+    transfer_flow = SantanderPaymentFlow(client, PIX_ENDPOINT)
+
     try:
         if value is None or value <= 0:
-            raise SantanderValueError(f"Invalid value for PIX transfer: {value}")
+            raise ValueError(f"Invalid value for PIX transfer: {value}")
 
-        transfer_flow = SantanderPaymentFlow(client, PIX_ENDPOINT, logger)
-
-        create_pix_dict = _generate_create_pix_dict(pix_key, value, description, tags)
+        create_pix_dict = _generate_create_pix_dict(
+            pix_key, value, description, tags, id
+        )
         create_pix_response = transfer_flow.create_payment(create_pix_dict)
         if not create_pix_response.get("id"):
             raise SantanderClientError("Payment ID was not returned on creation")
@@ -51,18 +50,28 @@ def transfer_pix(
         confirm_response = transfer_flow.confirm_payment(
             payment_data, create_pix_response.get("id")
         )
-        return {"success": True, "data": confirm_response, "error": ""}
+        return {
+            "success": True,
+            "request_id": transfer_flow.request_id,
+            "data": confirm_response,
+            "error": "",
+        }
     except Exception as e:
         error_message = str(e)
-        logger.error(error_message)
-        return {"success": False, "error": error_message, "data": None}
+        client.logger.error(error_message)
+        return {
+            "success": False,
+            "request_id": transfer_flow.request_id,
+            "error": error_message,
+            "data": None,
+        }
 
 
 def get_transfer(
     client: SantanderApiClient, pix_payment_id: str
 ) -> SantanderPixResponse:
     if not pix_payment_id:
-        raise SantanderValueError("pix_payment_id not provided")
+        raise ValueError("pix_payment_id not provided")
     response = client.get(f"{PIX_ENDPOINT}/{pix_payment_id}")
     return cast(SantanderPixResponse, response)
 
@@ -72,12 +81,17 @@ def _generate_create_pix_dict(
     value: D,
     description: str,
     tags: list = [],
+    id: uuid.UUID | str | None = None,
 ) -> dict:
     data = {
         "tags": tags,
         "paymentValue": truncate_value(value),
         "remittanceInformation": description,
     }
+
+    if id:
+        data["id"] = str(id)
+
     if isinstance(pix_key, str):
         pix_type = get_pix_key_type(pix_key)
         data.update({"dictCode": pix_key, "dictCodeType": pix_type})
@@ -86,10 +100,10 @@ def _generate_create_pix_dict(
     if isinstance(pix_key, dict):
         beneficiary = cast(dict, pix_key.copy())
         if beneficiary.get("bankCode") is None and beneficiary.get("ispb") is None:
-            raise SantanderValueError("Either 'bankCode' or 'ispb' must be provided")
+            raise ValueError("Either 'bankCode' or 'ispb' must be provided")
         if beneficiary.get("bankCode") and beneficiary.get("ispb"):
             beneficiary.pop("ispb")
-            data.update({"beneficiary": beneficiary})
+        data.update({"beneficiary": beneficiary})
     else:
-        raise SantanderValueError("PIX key or Beneficiary not provided")
+        raise ValueError("PIX key or Beneficiary not provided")
     return data
