@@ -4,17 +4,13 @@ import responses
 
 from santander_sdk.api_client.helpers import (
     download_file,
-    get_status_code_description,
     polling_until_condition,
     retry_one_time_on_request_exception,
     save_bytes_to_file,
     truncate_value,
     get_pix_key_type,
 )
-from santander_sdk.api_client.exceptions import (
-    SantanderRequestError,
-    SantanderValueError,
-)
+from santander_sdk.api_client.exceptions import SantanderRequestError
 
 
 def test_truncate_value():
@@ -34,18 +30,13 @@ def test_get_pix_key_type():
 
 
 def test_get_pix_key_type_invalid():
-    with pytest.raises(SantanderValueError):
+    with pytest.raises(ValueError):
         get_pix_key_type("234567890abcdef1234567890abcdef")
 
-    with pytest.raises(SantanderValueError):
+    with pytest.raises(ValueError):
         get_pix_key_type("55 34 12345678")
 
 
-def test_get_status_code_description():
-    assert get_status_code_description(200) == "200 - Sucesso"
-    assert get_status_code_description(392) == "392 - Erro desconhecido"
-
-
 @pytest.fixture
 def mock_sleep_time():
     with (
